@@ -40,8 +40,6 @@ class TaggingFormMixin(object):
             language = get_language()
             max_tags = self._get_tag_field_max_tags()
             user = None
-            if hasattr(self.instance, 'get_user'):
-                user = self.instance.get_user()
 
             data = self.data.get(self._get_tag_field_name())
             if not data:
@@ -67,14 +65,12 @@ class TaggingFormMixin(object):
                                 tag=tag,
                                 content_type=self._instance_ctype,
                                 object_id=self.instance.id,
-                                user=user,
                             )
                         )
                     else:
                         taggeditem = models.TaggedItem(
                             tag=tag,
-                            content_type=self._instance_ctype,
-                            user=user)
+                            content_type=self._instance_ctype)
                     self._taggeditems.append(taggeditem)
                 if max_tags and len(self._tags_added) > max_tags:
                     self._errors[self._get_tag_field_name()] = [
@@ -107,10 +103,12 @@ class TaggingFormMixin(object):
     def save(self, commit=True):
         instance = super(TaggingFormMixin, self).save(commit)
         for item in self._taggeditems:
+            if hasattr(instance, 'get_user'):
+                item.user = instance.get_user()
             item.object_id = instance.id
             item.save()
         models.TaggedItem.objects.filter(
             content_type=self._instance_ctype,
-            object_id=self.instance.id).exclude(
+            object_id=instance.id).exclude(
             pk__in=[ti.pk for ti in self._taggeditems]).delete()
         return instance
